function showAction(name, is_cut, select_num) {
    if (!select_num) {
        select_num = 1
    }
    api.actionSheet({
        title: '上传',
        cancelTitle: '取消',
        buttons: ['拍照', '从图库选择']
    }, function(ret, err) {
        if (ret) {
            if (ret.buttonIndex == 3) {
                return;
            }
            //请求权限判断：
            hasAndReqPermission('camera', '拍照', function () {
                getPicture(ret.buttonIndex, name, is_cut, select_num);
            });
        }
    });
}

function getPicture(sourceType, name, is_cut, select_num) {
    if (sourceType == 1 || select_num == 1) { // 拍照
        //获取一张图片
        api.getPicture({
            sourceType: sourceType == 1 ? 'camera' : 'library',
            encodingType: 'jpg',
            mediaValue: 'pic',
            allowEdit: false,
            quality: 80,
            targetWidth: 1080,
            saveToPhotoAlbum: true
        }, function(ret, err) {
            // 获取拍照数据并处理
            if (ret) {
                var imgSrc = ret.data;
                if (imgSrc != "") {
                    //调用图片裁剪：
                    if (is_cut) {
                        openCutting(imgSrc, name);
                    } else {
                        api.sendEvent({
                            name: name,
                            extra: {
                                imgsrc: imgSrc,
                            }
                        });
                    }
                }
            }
        });
    } else if (sourceType == 2) { // 从相机中选择
        //UIMediaScanner 是一个多媒体扫描器，可扫描系统的图片、视频等多媒体资源
        var obj = api.require('UIMediaScanner');
        obj.open({
            //返回的资源种类,picture（图片）,video（视频）,all（图片和视频）
            type: 'picture',
            //（可选项）图片显示的列数，须大于1
            column: 4,
            max: select_num,
            //（可选项）图片排序方式,asc（旧->新）,desc（新->旧）
            sort: {
                key: 'time',
                order: 'desc'
            },
            //（可选项）模块各部分的文字内容
            texts: {
                stateText: '选择图片',
                cancelText: '取消',
                finishText: '完成'
            },
            styles: {
                bg: '#fff',
                nav: {
                    bg: '#FFFFFF',
                    stateColor: '#666',
                    stateSize: 18,
                    cancleBg: 'rgba(0,0,0,0)',
                    cancelColor: '#666',
                    cancelSize: 18,
                    finishBg: 'rgba(0,0,0,0)',
                    finishColor: '#666',
                    finishSize: 18
                }
            },
            exchange: true
        }, function(ret) {
            // 获取图片数据并处理
            if (ret) {
                if (ret.list && ret.list.length > 0) {
                    //多张图片的选择：
                    if (ret.list.length > 1) {
                        var arr = [];
                        for (var i = 0; i < ret.list.length; i++) {
                            arr.push(ret.list[i].path);
                        }
                        transPathArr(arr, function(imgSrcArr) {
                            api.sendEvent({
                                name: name,
                                extra: {
                                    imgSrcArr: imgSrcArr,
                                }
                            });
                        });

                    } else {
                        transPath(ret.list[0].path, function(src) {
                            //调用图片裁剪：
                            if (is_cut) {
                                openCutting(src, name);
                            } else {
                                api.sendEvent({
                                    name: name,
                                    extra: {
                                        imgsrc: src,
                                    }
                                });
                            }
                        });
                    }
                }
            }
        });
    }
}

//图片地址的转换(主要针对iOS)
function transPath(imgSrcs, cb) {
    if (api.systemType == 'ios') {
        var UIMediaScanner = api.require('UIMediaScanner');
        UIMediaScanner.transPath({
            path: imgSrcs
        }, function(ret, err) {
            if (ret) {
                cb && cb(ret.path);
            } else {
                cb && cb('');
            }
        });
    } else {
        cb && cb(imgSrcs);
    }
}

//图片地址的转换(多个)
function transPathArr(arr, cb) {
    var srcs = [];
    var i = 0;
    transPathArrTo(srcs, arr, i, cb);
}
//图片地址的转换(多个)
function transPathArrTo(srcs, arr, i, cb) {
    transPath(arr[i], function(path) {
        i++;
        srcs.push(path);
        if (i >= arr.length) {
            cb && cb(srcs);
        } else {
            transPathArrTo(srcs, arr, i, cb);
        }
    });
}



//打开裁剪窗口：
function openCutting(imgSrcs, name) {
    openBackPage('图片裁剪', '/html/public/cutting_img.html', {
        imgSrcs: imgSrcs,
        bounces: 'NO',
        name: name
    });
}

//调用图片裁剪：
function fnImageClip(imgSrcs) {
    var imgWH = api.winWidth - 100;
    var params = api.pageParam,
        headerHeight = 0;
    if (params && params.headerHeight) {
        headerHeight = params.headerHeight;
    }
    var FNImageClip = api.require('FNImageClip');
    FNImageClip.open({
        rect: {
            x: 0,
            y: 0,
            w: api.winWidth,
            h: api.winHeight - headerHeight
        },
        srcPath: imgSrcs,
        style: {
            mask: 'rgba(1,1,1,0.6)',
            clip: {
                w: imgWH,
                h: imgWH,
                x: 50,
                y: (api.winHeight - headerHeight - imgWH) / 2,
                borderWidth: 1
            }
        },
        mode: 'image',
        fixedOn: api.frameName
    }, function(ret, err) {});
}

//保存图片裁剪：
function fnImageClipSave(imgSrcs, name) {
    var FNImageClip = api.require('FNImageClip');
    FNImageClip.save({
        destPath: imgSrcs,
        copyToAlbum: false,
        quality: 1
    }, function(ret, err) {
        if (ret) {
            submit_img(name, ret.destPath);
        } else {
            alert('出现错误，请重试！');
        }
    });
}

function submit_img(name, img) {
    api.sendEvent({
        name: name,
        extra: {
            imgsrc: img
        }
    });
    api.closeWin();
}
